@@ -1,9 +1,9 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-29'; # DATE
+our $DATE = '2021-07-30'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.027'; # VERSION
 
 use 5.010001;
 use strict;
@@ -316,7 +316,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.026 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-29.
+This document describes version 0.027 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-30.
 
 =head1 SYNOPSIS
 
@@ -368,6 +368,11 @@ to reduce startup overhead when doing tab completion.
 
 =head2 exclude_module
 
+Currently this means to exclude loading the specified schema module during
+build, skip resolving the schema, skip parsing the schema and extracting
+prerequisites from the schema, the and skip creating the corresponding
+C<Sah::SchemaR::*> module.
+
 =head1 CONTRIBUTOR
 
 =for stopwords Steven Haryanto
